%global sname oslo.config
%global pypi_name oslo-config
%global with_doc 1

%global repo_bootstrap 1

%if 0%{?fedora} > 23 || 0%{?rhel} >= 8
%global with_python3 1
%endif

%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

Name:       python-oslo-config
Epoch:      2
Version:    6.4.0
Release:    1%{?dist}
Summary:    OpenStack common configuration library

Group:      Development/Languages
License:    ASL 2.0
URL:        https://launchpad.net/%{sname}
Source0:    https://tarballs.openstack.org/%{sname}/%{sname}-%{upstream_version}.tar.gz

Patch0001: 0001-add-usr-share-project-dist.conf-to-the-default-confi.patch

BuildArch:  noarch
Requires:   python-oslo-i18n >= 3.15.3
Requires:   python-rfc3986 >= 0.3.1
Requires:   python-pbr
Requires:   python-requests >= 2.14.2
Requires:   python-six >= 1.10.0
Requires:   python-stevedore >= 1.20.0
Requires:   python-debtcollector >= 1.2.0
Requires:   python-enum34
Requires:   python-netaddr >= 0.7.18
Requires:   PyYAML >= 3.10

BuildRequires: python-devel
BuildRequires: python-setuptools
BuildRequires: python-oslo-i18n
BuildRequires: python-rfc3986
BuildRequires: python-pbr
BuildRequires: git
# Required for tests
BuildRequires: python-testscenarios
BuildRequires: python-testrepository
BuildRequires: python-testtools
BuildRequires: python-oslotest
BuildRequires: python-enum34
BuildRequires: python-requests-mock
BuildRequires: python-netaddr
BuildRequires: PyYAML
BuildRequires: python-stevedore

%if 0%{?repo_bootstrap} == 0
BuildRequires: python-oslo-log
%endif

%description
The Oslo project intends to produce a python library containing
infrastructure code shared by OpenStack projects. The APIs provided
by the project should be high quality, stable, consistent and generally
useful.

The oslo-config library is a command line and configuration file
parsing library from the Oslo project.

%if 0%{?with_doc}
%package -n python-%{pypi_name}-doc
Summary:    Documentation for OpenStack common configuration library
%{?python_provide:%python_provide python-%{pypi_name}-doc}

BuildRequires: python-fixtures
BuildRequires: python-openstackdocstheme
BuildRequires: python-oslotest >= 1.10.0
BuildRequires: python-sphinx
BuildRequires: python-stevedore

%description -n python-%{pypi_name}-doc
Documentation for the oslo-config library.
%endif

%if 0%{?with_python3}
%package -n python3-%{pypi_name}
Summary:    OpenStack common configuration library
%{?python_provide:%python_provide python3-%{pypi_name}}

Requires:   python3-netaddr >= 0.7.18
Requires:   python3-oslo-i18n >= 3.15.3
Requires:   python3-rfc3986 >= 0.3.1
Requires:   python3-pbr
Requires:   python3-requests >= 2.14.2
Requires:   python3-six >= 1.10.0
Requires:   python3-stevedore >= 1.20.0
Requires:   python3-debtcollector >= 1.2.0
Requires:   python3-PyYAML >= 3.10

BuildRequires: python3-devel
BuildRequires: python3-oslo-i18n
BuildRequires: python3-rfc3986
BuildRequires: python3-pbr
BuildRequires: python3-setuptools
BuildRequires: git
# Required for tests
BuildRequires: python3-fixtures
BuildRequires: python3-netaddr
BuildRequires: python3-openstackdocstheme
BuildRequires: python3-oslotest >= 1.10.0
BuildRequires: python3-six >= 1.10.0
BuildRequires: python3-stevedore
BuildRequires: python3-PyYAML
BuildRequires: python3-testscenarios
BuildRequires: python3-testrepository
BuildRequires: python3-testtools
BuildRequires: python3-oslotest
BuildRequires: python3-requests-mock

%if 0%{?repo_bootstrap} == 0
BuildRequires: python3-oslo-log
%endif

%description -n python3-%{pypi_name}
The Oslo project intends to produce a python library containing
infrastructure code shared by OpenStack projects. The APIs provided
by the project should be high quality, stable, consistent and generally
useful.

The oslo-config library is a command line and configuration file
parsing library from the Oslo project.
%endif

%prep
%autosetup -n %{sname}-%{upstream_version} -S git

# let RPM handle deps
rm -rf {test-,}requirements.txt

%build
%if 0%{?with_python3}
%py3_build
%endif
%py2_build

%if 0%{?with_doc}
export PYTHONPATH=.
sphinx-build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}
%endif

%install
%if 0%{?with_python3}
# we build the python3 version first not to crush the python
# version of oslo-config-generator
%py3_install
mv %{buildroot}%{_bindir}/oslo-config-generator \
   %{buildroot}%{_bindir}/python3-oslo-config-generator
%endif
%py2_install

%check
%if 0%{?repo_bootstrap} == 0
%{__python} setup.py test
%if 0%{?with_python3}
rm -rf .testrepository
%{__python3} setup.py test
%endif
%endif

%files
%doc README.rst
%license LICENSE
%{_bindir}/oslo-config-generator
%{python_sitelib}/oslo_config
%{python_sitelib}/*.egg-info

%if 0%{?with_doc}
%files -n python-%{pypi_name}-doc
%doc doc/build/html
%license LICENSE
%endif

%if 0%{?with_python3}
%files -n python3-%{pypi_name}
%doc README.rst
%license LICENSE
%{_bindir}/python3-oslo-config-generator
%{python3_sitelib}/oslo_config
%{python3_sitelib}/*.egg-info
%endif

%changelog
* Sat Aug 04 2018 RDO <dev@lists.rdoproject.org> 2:6.4.0-1
- Update to 6.4.0

